pub(crate) struct Opts {
pub(crate) pid: Option<u32>,
pub(crate) verbose: u8,
pub(crate) soft_dirty: bool,
pub(crate) perf_sample: bool,
pub(crate) perf_freq: u64,
pub(crate) json: bool,
pub(crate) interval: u64,
pub(crate) ring_mb: u32,
pub(crate) hints: bool,
pub(crate) hints_map: Option<String>,
}Expand description
scxcash: Cache Usage Analyzer for sched_ext Schedulers
Fields
pid: Option<u32>PID of the process to monitor for cache usage events.
verbose: u8Enable verbose output, including libbpf details. Specify multiple times to increase verbosity.
soft_dirty: boolEnable the soft-dirty cache monitor. If no monitor selection flags are provided, this monitor is enabled by default.
perf_sample: boolEnable perf sampling monitor (prototype: samples HW cycles for now).
perf_freq: u64Perf sampling frequency (samples per second).
json: boolOutput consumed monitor values as JSON (one per line). When not set, values are printed using Debug formatting.
interval: u64Interval in seconds between poll/consume cycles. Defaults to 1s.
ring_mb: u32Ring buffer size in megabytes (default is 4 MB).
hints: boolMonitor task-local storage updates for a hint map.
hints_map: Option<String>Pin path of the task hint TLS map (mandatory with –hints).